@@ -260,6 +260,7 @@ __all__ = (
     "ImageExistsWaiterName",
     "ImageStateType",
     "ImageTypeValuesType",
+    "ImdsSupportValuesType",
     "InstanceAttributeNameType",
     "InstanceAutoRecoveryStateType",
     "InstanceEventWindowStateType",
@@ -854,6 +855,7 @@ ImageAttributeNameType = Literal[
     "blockDeviceMapping",
     "bootMode",
     "description",
+    "imdsSupport",
     "kernel",
     "lastLaunchedTime",
     "launchPermission",
@@ -869,6 +871,7 @@ ImageStateType = Literal[
     "available", "deregistered", "error", "failed", "invalid", "pending", "transient"
 ]
 ImageTypeValuesType = Literal["kernel", "machine", "ramdisk"]
+ImdsSupportValuesType = Literal["v2.0"]
 InstanceAttributeNameType = Literal[
     "blockDeviceMapping",
     "disableApiStop",
@@ -1428,6 +1431,7 @@ InstanceTypeType = Literal[
     "u-12tb1.metal",
     "u-18tb1.metal",
     "u-24tb1.metal",
+    "u-3tb1.56xlarge",
     "u-6tb1.112xlarge",
     "u-6tb1.56xlarge",
     "u-6tb1.metal",
@@ -1895,7 +1899,9 @@ VolumeStateType = Literal["available", "creating", "deleted", "deleting", "error
 VolumeStatusInfoStatusType = Literal["impaired", "insufficient-data", "ok"]
 VolumeStatusNameType = Literal["io-enabled", "io-performance"]
 VolumeTypeType = Literal["gp2", "gp3", "io1", "io2", "sc1", "st1", "standard"]
-VpcAttributeNameType = Literal["enableDnsHostnames", "enableDnsSupport"]
+VpcAttributeNameType = Literal[
+    "enableDnsHostnames", "enableDnsSupport", "enableNetworkAddressUsageMetrics"
+]
 VpcAvailableWaiterName = Literal["vpc_available"]
 VpcCidrBlockStateCodeType = Literal[
     "associated", "associating", "disassociated", "disassociating", "failed", "failing"
@@ -1998,6 +2004,7 @@ ServiceName = Literal[
     "connect",
     "connect-contact-lens",
     "connectcampaigns",
+    "connectcases",
     "connectparticipant",
     "controltower",
     "cur",
@@ -2077,6 +2084,7 @@ ServiceName = Literal[
     "iotevents",
     "iotevents-data",
     "iotfleethub",
+    "iotfleetwise",
     "iotsecuretunneling",
     "iotsitewise",
     "iotthingsgraph",
@@ -2132,6 +2140,7 @@ ServiceName = Literal[
     "mgn",
     "migration-hub-refactor-spaces",
     "migrationhub-config",
+    "migrationhuborchestrator",
     "migrationhubstrategy",
     "mobile",
     "mq",
